Catalog Modules
====================
These modules contain the functions used 
to query external databases (including NED, 
PS1, and TNS) for data that astro_ghost needs
to run.

NEDQueryFunctions
-------------------------------------

.. automodule:: astro_ghost.NEDQueryFunctions
   :members:
   :undoc-members:
   :show-inheritance:

PS1QueryFunctions
-------------------------------------

.. automodule:: astro_ghost.PS1QueryFunctions
   :members:
   :undoc-members:
   :show-inheritance:

SimbadQueryFunctions
----------------------------------------

.. automodule:: astro_ghost.SimbadQueryFunctions
   :members:
   :undoc-members:
   :show-inheritance:

TNSQueryFunctions
-------------------------------------

.. automodule:: astro_ghost.TNSQueryFunctions
   :members:
   :undoc-members:
   :show-inheritance:
